# Changelog

<!-- prettier-ignore -->
Name | PR | Developer | Date | Version
--- | --- | --- | --- | ---
✨ Move docs | [4](https://github.com/laminlabs/laminci/pull/4) | [falexwolf](https://github.com/falexwolf) | 2023-02-23 | 0.2.0
🐛 Fix | [3](https://github.com/laminlabs/laminci/pull/3) | [falexwolf](https://github.com/falexwolf) | 2023-02-23 | 0.1.1
🚚 Move code from lndb | [2](https://github.com/laminlabs/laminci/pull/2) | [falexwolf](https://github.com/falexwolf) | 2023-02-23 | 0.1.0
🔥 Remove unnecessary files | [1](https://github.com/laminlabs/laminci/pull/1) | [falexwolf](https://github.com/falexwolf) | 2023-02-23 |
